@@ -380,7 +380,7 @@ class TTOpt():
         # If this is last iteration, we should "manually" check for y_opt_new:
         if is_last:
             i_min, y_min, opt_min = ttopt_find(
-                I, Y, self._opt, i_min, y_min, opt_min)
+                I, Y, self._opt, i_min, y_min, opt_min, self.is_max)
 
         if i_min is None:
             return Y, self._opt
@@ -403,7 +403,11 @@ class TTOpt():
             self.i_min_list.append(self.i_min.copy())
             self.x_min_list.append(self.x_min.copy())
 
-        is_better = len(self.y_min_list) == 1 or (y_min < self.y_min_list[-2])
+        if self.is_max:
+            is_better = len(self.y_min_list)==1 or (y_min > self.y_min_list[-2])
+        else:
+            is_better = len(self.y_min_list)==1 or (y_min < self.y_min_list[-2])
+
         if self.callback and is_better:
             last = {'last': [x_min, y_min, i_min, opt_min, self.k_evals]}
             self.callback(last)
@@ -461,7 +465,7 @@ class TTOpt():
 
         return text
 
-    def minimize(self, rmax=10, Y0=None, fs_opt=1., add_opt_inner=True, add_opt_outer=False, add_opt_rect=False, add_rnd_inner=False, add_rnd_outer=False, J0=None):
+    def minimize(self, rmax=10, Y0=None, fs_opt=1., add_opt_inner=True, add_opt_outer=False, add_opt_rect=False, add_rnd_inner=False, add_rnd_outer=False, J0=None, is_max=False):
         """Perform the function minimization process by TT-based approach.
 
         Args:
@@ -474,13 +478,24 @@ class TTOpt():
 
         """
         t_minim = tpc()
+        self.is_max = is_max
 
         i_min, y_min = ttopt(self.comp_min, self.n, rmax, None, Y0,
                 fs_opt, add_opt_inner, add_opt_outer, add_opt_rect,
-                add_rnd_inner, add_rnd_outer, J0)
+                add_rnd_inner, add_rnd_outer, J0, is_max)
 
         self.t_minim = tpc() - t_minim
 
+    def maximize(self, rmax=10, Y0=None, fs_opt=1., add_opt_inner=True, add_opt_outer=False, add_opt_rect=False, add_rnd_inner=False, add_rnd_outer=False, J0=None):
+        """Perform the function maximization process by TT-based approach.
+
+        Note:
+            See description of parameters in "minimize" function.
+
+        """
+        return self.minimize(rmax, Y0, fs_opt, add_opt_inner, add_opt_outer,
+            add_opt_rect, add_rnd_inner, add_rnd_outer, J0, is_max=True)
+
     def qtt_parse_many(self, I_qtt):
         """Transform tensor indices from QTT (long) to base (short) format."""
         samples = I_qtt.shape[0]
